@@ -8,7 +8,7 @@ use Data::Dumper;
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.12.1';
+our $VERSION = '0.04';
 
 # Subroutine for Error Handling MySQL Connection :
 # ------------------------------------------------------------------------
@@ -24,11 +24,7 @@ our $VERSION = '0.12.1';
     
 =cut
 sub errconn {
-
-	# Define parameter subroutine :
-	# ----------------------------------------------------------------
-	my $self = shift;
-
+	
 	# Define array for place error DBMS Connection :
 	# ----------------------------------------------------------------
 	my @data = ();
